Discover Packages
github.com/devr-tools/szr
internal
rules
package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: May 25, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type File struct {
Version int `json:"version,omitempty"`
Profiles []Profile `json:"profiles,omitempty"`
Preferences []Preference `json:"preferences,omitempty"`
}
type Match struct {
CommandPrefix []string `json:"command_prefix,omitempty"`
DisplayPrefix []string `json:"display_prefix,omitempty"`
AllArgs []string `json:"all_args,omitempty"`
AnyArgs []string `json:"any_args,omitempty"`
ExcludeArgs []string `json:"exclude_args,omitempty"`
CwdContains []string `json:"cwd_contains,omitempty"`
}
type Preference struct {
Name string `json:"name"`
Description string `json:"description,omitempty"`
Explain []string `json:"explain,omitempty"`
Match Match `json:"match"`
Rewrite Rewrite `json:"rewrite"`
}
type Profile struct {
Name string `json:"name"`
Description string `json:"description,omitempty"`
Explain []string `json:"explain,omitempty"`
Match Match `json:"match"`
Rewrite Rewrite `json:"rewrite,omitempty"`
Render Render `json:"render,omitempty"`
}
type Render struct {
Mode string `json:"mode,omitempty"`
MaxLines int `json:"max_lines,omitempty"`
}
type Rewrite struct {
Mode string `json:"mode,omitempty"`
Placement string `json:"placement,omitempty"`
Args []string `json:"args,omitempty"`
SkipIfHasAny []string `json:"skip_if_has_any,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.